# Security Policy

## Supported Versions

Version 1 or later of ASReview LAB receives security updates. Version 0.x is not supported.

## Reporting a Vulnerability

Please report vulnerabilities at https://github.com/asreview/asreview/security/advisories/new.
